## $Id: pdf.py 14454 2017-01-24 09:33:08Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Reusable components for pdf generation.
"""

import os
import grok
from reportlab.lib.pagesizes import A4, A3, landscape, portrait
from waeup.kofa.browser.pdf import PDFCreator, LandscapePDFCreator

class CustomPDFCreator(PDFCreator):
    """A utility to help with generating PDF docs. No watermark is shown.
    """

    header_logo_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_logo.jpg')
    #watermark_path = os.path.join(
    #    os.path.dirname(__file__), 'static', 'pdf_watermark.jpg')

    #watermark_pos = [70, 150]
    logo_pos = [500, 708, 60]

class CustomLandscapePDFCreator(LandscapePDFCreator):
    """A utility to help with generating PDF docs in
    landscape format. No watermark is shown.
    """

    header_logo_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_logo.jpg')
    #watermark_path = os.path.join(
    #    os.path.dirname(__file__), 'static', 'pdf_watermark.jpg')

    #watermark_pos = [200, 55]
    logo_pos = [750, 465, 60]

class A3LandscapePDFCreator(LandscapePDFCreator):
    """A utility to help with generating PDF docs in
    A3 landscape format. No watermark is shown.
    """

    grok.name('A3landscape')

    header_logo_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_logo.jpg')
    #watermark_path = os.path.join(
    #    os.path.dirname(__file__), 'static', 'pdf_watermark.jpg')

    #watermark_pos = [360, 150]
    logo_pos = [1100, 710, 60]
    pagesize = landscape(A3)
